%RIG v. 1.0 (May 2010)
%--------------------------------------------------------------------------
%calculates stress / strain curves and much more from a digital chart record.
%input: time (s), force (V), confining pressure (V), Displacement (V), DLT
%displacement (microns) - optional
%
%First, use the native import of matlab (file>importdata) to import your data
%in your preffered format (tab, comma or whatever separated text files). 
%The data HAVE to be column vectors with the variable names ti fi pci dxi (DLTi) 
%(During data import click "Create vectors from each column using column names.")
%in the end you are supposed to have variables ti, fi etc. in your workspace
%(i.e ti <28646x1 double>)
%
%troubleshooting: if you can't import a file open it in Textwrangler or any
%other texeditor end select the option "show invisibles" usually there are
%some extra weird symbols after the 4/5 columns - just select one line and do
%"search and replace" to get rid of them.
%
%An example datafile is in the folder "files" for inspiration...
%
%All calibrations are for the Tromso rigs.
%
%Based on the programs RigPrep, RigS4 and RigC4 by R. Heilbronner, A.
%DeRonde and many others
%
%Basel,Tromso, 2009-2010, Matej Pec (with many usefull comments from
%Ruediger Kilian & Renne Heilbronner), function txtwrite & getpoly written by Ondrej Lexa 2003
%for polyLX toolbox (http://petrol.natur.cuni.cz/~ondro/polylx:home)
%
%any bug reports / suggestions are welcome on matej.pec@unibas.ch or
%matej.pec@seznam.cz
%
%--------------------------------------------------------------------------
%!!!!!Do NOT use me like a black-box, read how I calculate your data!!!!!
%        ...otherwise, you will be struck down by a lightning...
%--------------------------------------------------------------------------

%--------------------------------------------------------------------------
%data import

%filename = input ('enter filename ','s');
%importfile (filename); %both lines (39,40) can be commented if manual data import is preferred

%--------------------------------------------------------------------------
%define hit-point (see function HP.m) 

%[xintersect,yintersect,fit1]=HP(ti,fi,dxi);

%--------------------------------------------------------------------------

name = input ('Experiment number/name? ','s'); %reads the name of the experiment

%--------------------------------------------------------------------------
%which rig was used?

RIG = input ('Apparatus: rig1 (1) or rig2 (2)? ');

if (RIG == 1)
    
    [tsec,tmin,thour,tday,fCkN,dxC,dxStiffCor,pcC,pcMPa]=RIG1Aconversion(ti,fi,dxi,pci); %calls function RIG1conversion, uses DC-DT data for displacement,
    
    %----------------------------------------------------------------------
    %plot F (kN) Pc(MPa) & Dx(mm) corrected for rig stiffnes 
    %and uncorrected vs. t (min) to check if data is ok
    
    figure
    plot(tmin,dxC,'b');
    title('blue=DC-DT, cyan=DC-DT rig stiffnes corrected');
    xlabel('Time (min)');
    ylabel('Displacemnt - HP (mm)');
    
    hold on
    
    plot(tmin,dxStiffCor,'c');
    
    hold off
    
    figure
    plot(tmin,fCkN,'r');
    title(name);
    xlabel('Time (min)');
    ylabel('Force - HP (kN)');
    
    figure
    plot(tmin,pcC,'g');
    title(name);
    xlabel('Time (min)');
    ylabel('Confining Pressure - HP (MPa)');
    
else
    
    [tsec,tmin,thour,tday,dxC,dxStiffCor,pcC,pcMPa,fCkN]=RIG2Aconversion(ti,fi,dxi,pci); %calls function RIG2conversion, uses DLT data for displacement
    
    %----------------------------------------------------------------------
    %plot F (kN) Pc(MPa) & Dx(mm) corrected for rig stiffnes and
    %uncorrected vs. t (min) to check if data is ok
    
    figure
    plot(tmin,dxC,'b');
    title('blue=DC-DT, cyan=DC-DT rig stiffnes corrected');
    xlabel('Time (min)');
    ylabel('Displacemnt - HP (mm)');
    
    hold on
    
    plot(tmin,dxStiffCor,'c');
    
    hold off
    
    figure
    plot(tmin,fCkN,'r');
    title(name);
    xlabel('Time (min)');
    ylabel('Force - HP (kN)');
    
    figure
    plot(tmin,pcC,'g');
    title(name);
    xlabel('Time (min)');
    ylabel('Confining Pressure - HP (MPa)');
    
    %dxStiffCor=DLTStiffCor; %assignes DLT data to variable dxStiffCor for further calculation so that the same code can be used for rig1 & 2, this can be removed as soon as DLT is installed on rig1 as well
end


%--------------------------------------------------------------------------
%type of experiment?

extype = input ('Data of axial (1) or shear (2) experiment? ');

if (extype == 1)
    [strain,strainrateeng,strainratenat,sdif,sdifAreaCor,sdifrawAreaCor,disrate]=rigCA(dxC,dxStiffCor,fCkN,pcC,tmin,tsec,name); %calls function rigC
    
    %writes comma separated textfile for kaleidagraph ploting ;-)
    txtwrite ([{'t (sec)','t (min)','t (hour)','t (day)','differential stress raw (MPa)','differential stress corrected (MPa)','force(kN)', ...
    'Confining pressure from HP (MPa)','displacement raw (mm)','displacement (mm)','strain (%)','displacement rate (mm/sec)', ...
    'engineering strainrate (/sec)','natural strainrate (/sec)'}; ... %,'y-intersect of run-in curve (kN)','y-intersect of run-in curve (MPa)','slope of run-in curve'
    num2cell(tsec) num2cell(tmin) num2cell(thour) num2cell(tday) num2cell(sdif) num2cell(sdifAreaCor) num2cell(fCkN) num2cell(pcC) num2cell(dxC) ...
    num2cell(dxStiffCor) num2cell(strain) num2cell(disrate) num2cell(strainrateeng) num2cell(strainratenat)],[name '_coax.txt']); %num2cell(runinintersectkN) num2cell(runinintersectMPa) num2cell(fit1(1,1))
else
    [tau,gamma,sdif,shearrateI,shearrateF,shearrateR,disrate,ACFcontact,contact]=rigSA(dxStiffCor,dxC,fCkN,pcC,tmin,tsec,name); %calls function rigS
   
    %writes comma separated textfile for kaleidagraph ploting
    txtwrite ([{'t (sec)','t (min)','t (hour)','t (day)','differential stress (MPa)','shear stress (MPa)','force(kN)','Confining pressure from HP (MPa)' ...
    ,'displacement raw (mm)','displacement (mm)','gamma','displacement rate (mm/sec)','instantaneous shear strain rate (/sec)', ...
    'finite shear strain rate (/sec)', 'shear strain rate renee (/sec)'}; num2cell(tsec) num2cell(tmin) ... %'y-intersect of run-in curve (kN)','y-intersect of run-in curve (MPa)','slope of run-in curve'
    num2cell(thour) num2cell(tday) num2cell(sdif) num2cell(tau) num2cell(fCkN) num2cell(pcC) num2cell(dxC) num2cell(dxStiffCor) num2cell(gamma) ...
    num2cell(disrate) num2cell(shearrateI) num2cell(shearrateF) num2cell(shearrateR)],[name '_shear.txt']); % num2cell(runinintersectkN) num2cell(runinintersectMPa) num2cell(fit1(1,1))

end
