function [strain,strainrateeng,strainratenat,sdif,sdifAreaCor,sdifrawAreaCor,disrate]=rigCA(dxC,dxStiffCor,fCkN,pcC,tmin,tsec,name) %[strain,strainrate,]=

%performs strain, stress, strain rate calculations for coaxial experiments
%Matej Pec 2010

%last check 1.6.2010, works perfectly

%--------------------------------------------------------------------------
%calculate sigma1 displacement rate (delta L/delta t [mm/sec]) with dx
%corrected for rig stiffness

disrate=zeros(size(tsec));%prelocating matrix for higher calculation speed
for x=2:length(tsec);
    disrate(x)=(dxStiffCor(x)-dxStiffCor(x-1))/(tsec(x)-tsec(x-1));
end

%calculate sigma1 displacement rate (delta L/delta t [mm/sec]) with dx
%NOT corrected for rig stiffness

disrateNoCor=zeros(size(tsec));%prelocating matrix for higher calculation speed
for x=2:length(tsec);
    disrateNoCor(x)=(dxC(x)-dxC(x-1))/(tsec(x)-tsec(x-1));
end
%--------------------------------------------------------------------------
%read sample dimensions etc. for coaxial experiments

sdia= input ('Sample diameter (mm): ');
slen= input ('Sample lenght (mm): ');

%--------------------------------------------------------------------------
%calculate strain

e=zeros(size(fCkN));%prelocating matrix for higher calculation speed
for x=1:length(dxStiffCor)
    e(x)=slen-dxStiffCor(x);
end

strainraw=e/slen; 
strain=(1-strainraw)*100; %recalculate to %

%--------------------------------------------------------------------------
%calculates engineering (instantaneous) and natural (finite) strain rate
%using displacement rate corrected for rig stiffness

strainrateeng=zeros(size(fCkN));%prelocating matrix for higher calculation speed
for x=1:length(fCkN);
    strainrateeng(x)=disrate(x)/e(x);
end

strainratenat=zeros(size(fCkN));%prelocating matrix for higher calculation speed
for x=1:length(fCkN);
    strainratenat(x)=disrate(x)/slen;
end

%----------------------------------------------------------------------
%calculates differential stress, correction for increasing sample diameter

fN=fCkN*1000; % convert kN to N
area=(pi*(sdia*sdia))/4; %area in mm2, N/mm2 = MPa since N/m2=Pa

sdifNoCor=zeros(size(fCkN)); %prelocating matrix for higher calculation speed
sdifrawAreaCor=zeros(size(fCkN));
for x=1:length(fCkN)
    sdifrawAreaCor(x)=fN(x)*strainraw(x)/area;
    sdifNoCor(x)=fN(x)/area; %no changing diameter correction
end

%--------------------------------------------------------------------------
%correction for confining pressure change during run,

pccorrection= input ('Do you want to correct for changing confining pressure during experiment run (y/n)? ' ,'s');

if pccorrection == 'y';
    sdif = sdifNoCor - pcC;
    sdifAreaCor = sdifrawAreaCor - pcC;
    
    %----------------------------------------------------------------------
    %plots Pc corrected and uncorrected stress-strain curves to check if
    %data is ok
    
    figure
    plot(tmin,sdif,'m');
    title('blue = uncorrected, magenta= Pc corrected');
    xlabel('Time (min)');
    ylabel('stress (MPa)');
    
    hold on
    
    plot(tmin,sdifNoCor,'b')
    
    hold off
    
else
    sdif = sdifNoCor;
    sdifAreaCor = sdifrawAreaCor;
end

%--------------------------------------------------------------------------
%plots strainrate and stress-strain (including area correction)

figure
plot(tmin,disrate,'b');
title('       blue=displ. rate corrected for rig stiffnes; magenta=NOT corrected for rig stiffness');
xlabel('t (min)');
ylabel('displacement rate (mm/sec)');

hold on

plot(tmin,disrateNoCor,'m');
xlabel('t (min)');
ylabel('displacement rate (mm/sec)');

hold off

figure
plot(strain,sdif,'c');
title('cyan=differential stress; blue=differential stress corrected for area change');
xlabel('stain(%)');
ylabel('strain rate (sec^-1)');

hold on

plot(strain,sdifAreaCor,'b');

hold off

figure
plot(tmin,strainrateeng,'m');
title('magenta=engineering strain rate; blue=natural strain rate');
xlabel('Time (min)');
ylabel('strain rate (sec^-1)');

hold on

plot(tmin,strainratenat,'b');

hold off

figure
plot(strain,sdifAreaCor,'k');
title(name);
xlabel('strain (%)');
ylabel('stress (MPa)');