 function [tau,gamma,sdif,shearrateI,shearrateF,shearrateR,disrate,ACFcontact,contact]=rigSA(dxStiffCor,dxC,fCkN,pcC,tmin,tsec,name)

%performs gamma, shear stress, shear strain rate calculations for shear experiments
%Matej Pec 2010

%last check 1.6.2010 - works perfectly

%--------------------------------------------------------------------------
%calculate sigma1 displacement rate (delta L/delta t [mm/sec]) with dx
%corrected for rig stiffness

disrate=zeros(size(tsec));%prelocating matrix for higher calculation speed
for x=2:length(tsec);
    disrate(x)=(dxStiffCor(x)-dxStiffCor(x-1))/(tsec(x)-tsec(x-1));
end

%calculate sigma1 displacement rate (delta L/delta t [mm/sec]) with dx
%NOT corrected for rig stiffness

disrateNoCor=zeros(size(tsec));%prelocating matrix for higher calculation speed
for x=2:length(tsec);
    disrateNoCor(x)=(dxC(x)-dxC(x-1))/(tsec(x)-tsec(x-1));
end

%--------------------------------------------------------------------------
%read sample dimensions etc. for shear experiments

sdia= input ('Sample diameter (mm): ');
alfa= input ('Angle of shear zone w/r axis (degrees): ');
th0= input ('Original thicknes of the shear zone (mm): ');
thf= input ('Final thickness AFTER deformation (mm): ');

%----------------------------------------------------------------------
%calculates differential stress

fN=fCkN*1000; % convert kN to N
area=(pi*(sdia*sdia))/4; %area in mm2, N/mm2 = MPa since N/m2=Pa

sdifNoCor=zeros(size(tmin)); %prelocating matrix for higher calculation speed

for x=1:length(tmin)
    sdifNoCor(x)=fN(x)/area; %constant forcing block diameter assumed
end

% %--------------------------------------------------------------------------
% %calculate y-intersect of run in curve (in kN and MPa)
% 
% v=fit1(1,2)/1000; % convert into volts - Tromso specific
% runinintersectkN=v*fConkN;
% runinintersectMPa=v*fConkN*1000/area; % convert kN to N, area in mm2, N/mm2 = MPa since N/m2=Pa

%--------------------------------------------------------------------------
%correction for confining pressure change during run,

pccorrection= input ('Do you want to correct for changing confining pressure during experiment run (y/n)? ' ,'s');

if pccorrection == 'y';
    sdif = sdifNoCor - pcC;
    
    %----------------------------------------------------------------------
    %plots Pc corrected and uncorrected stress-strain curves to check if
    %data is ok
    
    figure
    plot(tmin,sdif,'c');
    title('blue = uncorrected, cyan= Pc corrected');
    xlabel('Time (min)');
    ylabel('diferential stress (MPa)');
    
    hold on
    
    plot(tmin,sdifNoCor,'b')
    
    hold off
    
else
    sdif = sdifNoCor; 
end

%----------------------------------------------------------------------
%calculate total dz1 and proportion, ...

alfa = alfa * (pi/180); %recalculates alfa to radians
SZlength=sdia/sin(alfa); %shear zone length
dz1tot = (th0-thf) / sin(alfa); 
proportion = dz1tot / dxStiffCor(length(tmin)); 

%----------------------------------------------------------------------
%resolve vertical displacement into dz1 and dz2 and simple shear
%displacement (see manual for mor info)

dz1=zeros(size(tmin)); %prelocating matrix for higher calculation speed
dz2=zeros(size(tmin)); %prelocating matrix for higher calculation speed
th=zeros(size(tmin)); %prelocating matrix for higher calculation speed
dzsimple=zeros(size(tmin)); %prelocating matrix for higher calculation speed

for x=1:length(tmin)
    dz1(x) = proportion * dxStiffCor(x);
    dz2(x) = dxStiffCor(x) - dz1(x);
    th(x)  = th0 - dz1(x) * sin(alfa);
    dzsimple(x)  = dz2(x) / cos(alfa);
end

%----------------------------------------------------------------------
%calculate shear strain

gamma=zeros(size(tmin)); %prelocating matrix for higher calculation speed
for x=1:length(tmin)
    gamma(x)  = dzsimple(x) / th(x);
end

%----------------------------------------------------------------------
%simple slip correction

slip=zeros(size(tmin)); %prelocating matrix for higher calculation speed
contact=zeros(size(tmin)); %prelocating matrix for higher calculation speed

for x=1:length(tmin)
    slip(x) = th(x)/tan(alfa);
    contact(x) =  dzsimple(x) / SZlength;
end
%----------------------------------------------------------------------
%3rd order polynomial fit to plot profile of ACF of circle (NIHImage)
%NOT-modified to calculate ACF of negative x   Renne Heilbronner 20.8.04

ACFcontact=zeros(size(tmin)); %prelocating matrix for higher calculation speed

for x=1:length(tmin)
    ACFcontact(x)= 1.00 - 1.2082*contact(x) - 0.19134*(contact(x)*contact(x)) + 0.39461*(contact(x)*contact(x)*contact(x));
end

%----------------------------------------------------------------------
%shear stress

tau=zeros(size(tmin)); %prelocating matrix for higher calculation speed

for x=1:length(tmin)
    tau(x) = 0.5 * sdif(x) / ACFcontact(x); %why 0.5 ??? isn't this a hidden 45? assumption??????
end

%----------------------------------------------------------------------
%instantaneous (engineering) & finite (natural) shear strain rate (see
%Twiss & Moores,2007, Structural Geology, 2nd edition, pp 465-466 "Measures of strain rate") 

shearrateI=zeros(size(tmin));
shearrateF=zeros(size(tmin));
shearrateR=zeros(size(tmin));

for x=2:length(tmin)
    shearrateI(x)=(0.5*((dzsimple(x)-dzsimple(x-1))/(tsec(x)-tsec(x-1))))/th(x); %instantaneous shear strain rate (Twiss&Moors 2007)
end

for x=2:length(tmin)
    shearrateF(x)=(0.5*((dzsimple(x)-dzsimple(x-1))/(tsec(x)-tsec(x-1))))/th0; %finite shear strain rate (Twiss&Moors 2007)
end

for x=2:length(tmin)
    shearrateR(x)=((gamma(x)-gamma(x-1))/(tsec(x)-tsec(x-1))); %ren?es shear strain rate
end

figure
plot(tmin,disrate,'b');
title('blue=displacement rate corrected for rig stiffnes; magenta=NOT corrected for rig stiffness');
xlabel('t (min)');
ylabel('displacement rate (mm/sec)');

hold on

plot(tmin,disrateNoCor,'m');
xlabel('t (min)');
ylabel('displacement rate (mm/sec)');

hold off

figure
plot(tmin,shearrateI,'m');
title('magenta=instantaneous strain rate; blue=finite strain rate; red=delta gamma/delta t');
xlabel('t (min)');
ylabel('shear strain rate (/sec)');

hold on

plot(tmin,shearrateF,'b');
xlabel('t (min)');
ylabel('shear strain rate (/sec)');

plot(tmin,shearrateR,'r');
xlabel('t (min)');
ylabel('shear strain rate (/sec)');

hold off

figure
plot(gamma,tau,'k');
title(name);
xlabel('gamma');
ylabel('shear stress (MPa)');