function [xintersect,yintersect,fit1,fit2,no,f,pc,dx,ti,tiorig,slopef,slopedx,slopepc,DLT]=HP(RIG,ti,fi,dxi,pci,varargin)
%--------------------------------------------------------------------------
%hitpoint definition: plots raw force & displacement curves vs. time increment,
%reduces tha data points by a user defined value and smooths them with a
%zero-phase forward and reverse digital filtering.
%further allows selecting of force curve segments for linear regresion fit and
%calculates the x- & y-intersection of these curves. 
%(selectable plot based on pcsd.m & getpoly.m from the polyLX toolbox programmed by
%Ondrej Lexa 2001) Matej Pec 2010

%--------------------------------------------------------------------------
%data reduction, consider reducing your points if you have more than 
%300 000 data points (depending on your CPU power)

tiorig=ti; %saves original ti
%tstart=tiorig(1,1);  % reads the first input of ti (to get correct tHPfromstart if also pumping was recorded) conversion to seconds is in conversions.m


if length(ti)>100000; %check filesize
    z = input ('data reduction, every Xth point will be considered (consider if you have > ca. 200 000 data points) '); %250 000 filtfilt doesn't work, 84 000 ok
    
    fi=fi(1:z:numel(fi));
    dxi=dxi(1:z:numel(dxi));
    pci=pci(1:z:numel(pci));
    ti=ti(1:z:numel(ti));
    
    if nargin>5
        DLTi=varargin{:};
        DLTi=DLTi(1:z:numel(DLTi));
    end
else
end

%--------------------------------------------------------------------------
%data smoothing
no = input ('select the number of points you want to use for running average filtering (i.e. 100) ');

b=zeros(size(no)); %prelocating matrix
for x=1:no %creates a vector for forward & reverse moving average filter 
    b(x)=1/no;
end

f=filtfilt(b,1,fi); %Zero-phase forward and reverse digital filtering
dx=filtfilt(b,1,dxi);
pc=filtfilt(b,1,pci);

g=exist('z','var'); % check if DLT was already assigned during datareduction or not
if g == 0 && RIG == 2
    DLTi=varargin{:};
else
end

if nargin>5
    DLT=filtfilt(b,1,DLTi);
end

%--------------------------------------------------------------------------
%plot
plot(ti,fi,'r');
hold on
plot(ti,f,'m--');
plot(ti,pci,'g');
plot(ti,pc,'c--');
plot(ti,dxi,'b');
plot(ti,dx,'c--');

title('zoom-in to your hit-point and then press ENTER, dashed lines = smoothed data');
xlabel('Time (input)');
ylabel('mV');
%legend('Force raw','Force smooth','Confining Pressure raw','Confining Pressure smooth','displacement raw','displacement smooth','Location','NorthWestOutside');

pause
dummy = input ('' ,'s'); %just to absorb the hit of any key to break the pause

%--------------------------------------------------------------------------
%fit chosen data (run-in)

title('Click a polygon enclosing data for linear regression on the force curve, start with the RUN-IN curve:');
[xx,yy]=getpoly;
if length(xx)>2
   ix=inpolygon(ti,f,xx,yy);
else
   ix=1:length(f);
end
if isempty(find(ix)), ix=1:length(f); end  % take all

fit1=polyfit(ti(ix),f(ix),1);
runin=fit1(1,1)*ti + fit1(1,2);
plot(ti,runin,'k--');

%--------------------------------------------------------------------------
%fit chosen data ("elastic" slope)

[xx,yy]=getpoly;
if length(xx)>2
   ix=inpolygon(ti,f,xx,yy);
else
   ix=1:length(f);
end
if isempty(find(ix)), ix=1:length(f); end  % take all

fit2=polyfit(ti(ix),f(ix),1);
elastic=fit2(1,1)*ti + fit2(1,2);
plot(ti,elastic,'k--');

%--------------------------------------------------------------------------
%find x & y intersection of the line fits thru force

xintersect=(fit1(1,2)-fit2(1,2))/(fit2(1,1)-fit1(1,1));
yintersect=((fit1(1,2)*fit2(1,1))-(fit2(1,2)*fit1(1,1)))/(fit2(1,1)-fit1(1,1));

xintersect=int32(xintersect); %rounds up x-intersection to next integer 


%--------------------------------------------------------------------------
%quick & dirty use of traditional HP - rewrite
%correctly!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
% for x=xintersect:xintersect+1500
%     f(x)=elastic(x);
% end

%--------------------------------------------------------------------------
%plot linear regresion lines thru dx considering the same hit-point as in
%force

% fit3=polyfit(ti(1:xintersect),dxi(1:xintersect),1);
% runindx=fit3(1,1)*ti + fit3(1,2);
% 
% fit4=polyfit(ti(xintersect:length(ti)),dxi(xintersect:length(dxi)),1);
% elasticdx=fit4(1,1)*ti + fit4(1,2);

%plot(ti,runindx,'c--');
%plot(ti,elasticdx,'c--');

hold off

%--------------------------------------------------------------------------
%discards data before hit-point
% 
c=exist('z','var'); % check if datareduction has been used

if c==1
    cut=find(ti == xintersect); %find the position of x-intersect
    d=isempty(cut); %check if an intersect has been found
    if d ==1
        e=0;
        while d==1
        e=e+1;    
        cut=find(ti == xintersect-e); %try before, it would be nicer if he would go back and forth but somehow I didn't get it to work...
        d=isempty(cut); %check if an intersect has been found
        end
    end
else
    cut=find(ti == xintersect);
end

fic=f;
dxc=dx;
pcc=pc;

f=f(cut:length(f),:); %discards data before hit-point
dx=dx(cut:length(dx),:);
pc=pc(cut:length(pc),:);
ti=ti(cut:length(ti),:);

if nargin>5
DLT=DLT(cut:length(DLT),:);
end


%--------------------------------------------------------------------------
%calculates slope of run in curve at given time intervals


deltat = input ('select the time input interval for derivation ');

fred=fic(1:deltat:numel(fic));

for k=2:length(fred);
    slopef(k)=(fred(k))-fred(k-1);
end

dxred=dxc(1:deltat:numel(dxc));

for k=2:length(fred)
    slopedx(k)=(dxred(k))-dxred(k-1);
end

pcred=pcc(1:deltat:numel(pcc));

for k=2:length(fred)
    slopepc(k)=(pcred(k))-pcred(k-1);
end


% figure
% plot(slope)
% hold on
% plot(fic-min(fic),'r')

% fConkN = 22.0344;
%     
% slopekN= (slope/1000)*fConkN; %kN



