%RIG v. 1.2 (April 2011)
%
%changelog: 
%27/11/10 - calculates first derivative (slope) of force,dx & pc thru whole run
%           at given time intervals
%
%--------------------------------------------------------------------------
%calculates stress / strain curves and much more from a digital chart record.
%input: time (s), force (V), confining pressure (V), Displacement (V), DLT
%displacement (microns) - optional
%
%First, use the native import of matlab (file>importdata) to import your data
%in your preffered format (tab, comma or whatever separated text files). 
%The data HAVE to be column vectors with the variable names "ti","fi","pci","dxi",("DLTi") 
%(During data import click "Create vectors from each column using column names.")
%in the end you are supposed to have variables ti, fi etc. in your workspace
%(i.e ti <28646x1 double>)
%
%troubleshooting: if you can't import a file open it in Textwrangler or any
%other texteditor end select the option "show invisibles" usually there are
%some extra weird symbols after the 4th/5th column - just select one line and do
%"search and replace" to get rid of them.
%
%An example datafile is in the folder "files" for inspiration...
%
%All calibrations are for the Tromso rigs.
%
%Based on the programs RigPrep, RigS4 and RigC4 by R. Heilbronner, A.
%DeRonde and many others
%
%Basel,Tromso, 2009-2010, Matej Pec (with many usefull comments from
%Ruediger Kilian,Renee Heilbronner, Ondrej Lexa & Petr Jerabek), function txtwrite & getpoly written
%by Ondrej Lexa 2003 for polyLX toolbox 
%(http://petrol.natur.cuni.cz/~ondro/polylx:home)
%many thanks to Anja Thust & Marianne Negrini for beta-testing 
%
%any bug reports / suggestions are welcome on matej.pec@unibas.ch or
%matej.pec@seznam.cz
%
%--------------------------------------------------------------------------
%!!!!!Do NOT use me like a black-box, read how I calculate your data!!!!!
%        ...otherwise, you will be struck down by a lightning...
%--------------------------------------------------------------------------

%--------------------------------------------------------------------------
%define hit-point (see function HP.m) 

RIG = input ('Apparatus: rig1 (1) or rig2 (2)? '); % which rig was used?

if RIG==2 
    [xintersect,yintersect,fit1,fit2,no,f,pc,dx,ti,tiorig,slopef,slopedx,slopepc,DLT]=HP(RIG,ti,fi,dxi,pci,DLTi);
else
    [xintersect,yintersect,fit1,fit2,no,f,pc,dx,ti,tiorig,slopef,slopedx,slopepc]=HP(RIG,ti,fi,dxi,pci);
end

%--------------------------------------------------------------------------

name = input ('Experiment number/name? ','s'); %reads the name of the experiment

%--------------------------------------------------------------------------
%call function conversions.m to convert data from volts to sec,kN,MPa,mm etc. 

if RIG==2
    [tHPfromstart,ts,tsec,tmin,thour,tday,fCkN,dxC,dxStiffCor,pcC,pcMPa,fHPkN,RigStiff,Friction,frict,pcCon,dxCon,fConkN,slopemm,slopekN,slopeMPa,DLTC,DLTStiffCor]=conversions(ti,tiorig,f,dx,pc,xintersect,RIG,slopef,slopedx,slopepc,DLT);
else 
    [tHPfromstart,ts,tsec,tmin,thour,tday,fCkN,dxC,dxStiffCor,pcC,pcMPa,fHPkN,RigStiff,Friction,frict,pcCon,dxCon,fConkN,slopemm,slopekN,slopeMPa]=conversions(ti,tiorig,f,dx,pc,xintersect,RIG,slopef,slopedx,slopepc);
end
    
    %----------------------------------------------------------------------
    %plot F (kN) Pc(MPa) & Dx(mm) corrected for rig stiffnes 
    %and uncorrected vs. t (min) to check if data is ok
    
    figure
    plot(tmin,dxC,'b--');
    title(name);
    xlabel('time (min)');
    ylabel('displacement (mm)');
    hold on
    
    plot(tmin,dxStiffCor,'b');
    legend('displacement DC-DT','displacement DC-DT corrected for RigStiffnes','Location','NorthWest');
    
    if RIG==2
        plot(tmin,DLTC,'c--');
        plot(tmin,DLTStiffCor,'c');
        legend('displacement DC-DT','displacement DC-DT corrected for RigStiffnes','displacement DLT','displacement DLT corrected for RigStiffnes','Location','NorthWest');
        hold off
    else
    end
    
    figure
    plot(tmin,fCkN,'r');
    title(name);
    xlabel('time (min)');
    ylabel('force (kN)');
    legend('force','Location','NorthWest');
    
    figure
    plot(tmin,pcC,'g');
    title(name);
    xlabel('time (min)');
    ylabel('delta confining pressure from hit-point (MPa)');
    legend('confining pressure');
    hold off
    
    figure
    plot(slopekN,'r');
    hold on
    plot(slopemm,'b');
    plot(slopeMPa,'g');
    xlabel('t');
    ylabel('slope [mm/sec, resp kN/sec, MPa/sec]');

%--------------------------------------------------------------------------
%if DLT data is present use it instead of DC-DT data

if RIG==2
    dxStiffCor=DLTStiffCor;
    dxC=DLTC;
else
end
 
%--------------------------------------------------------------------------
%type of experiment?

extype = input ('Data of axial (1) or shear (2) experiment? ');


if (extype == 1) %Coaxial experiments
    [sdia,area,slen,pccorrection,strain,strainrateeng,strainratenat,sdifNoCor,sdif,sdifrawAreaCor,sdifAreaCor, ...
    strainraw,disrateNoCor,disrate,runinintersectkN,runinintersectMPa,HPkN]=rigC(dxStiffCor,dxC,fCkN,pcC,tmin, ...
    tsec,name,fConkN,fit1,yintersect); %calls function rigC
    
    %----------------------------------------------------------------------
    %writes a tab separated textfile using fprintf (order of magnitude
    %faster than txtwrite), variable A contains all values to be printed,
    %first fprintf prints the header
    
    A=[tsec tmin thour tday sdifNoCor sdifrawAreaCor sdifAreaCor fCkN pcC pcMPa dxC dxStiffCor strain disrate strainrateeng strainratenat];
    fid= fopen([name '_coax.txt'],'wt');
    fprintf(fid,'t(sec)\tt(min)\tt(hour)\tt(day)\tdif_stress_raw (MPa)\tdif_stress_corrected_for_changing_area(MPa)\tdif_stress_corrected_for_Pc_and_changing_area(MPa)\tforce(kN)\tdelta_confining_pressure(MPa)\tconfining_pressure(MPa)\tdisplacement_raw(mm)\tdisplacement(mm)\tstrain\tdisplacement_rate(mm/sec)\tinstantaneous_strain_rate(/sec)\tfinite_strain_rate(/sec)\n');
    fprintf(fid,'%g\t%g\t%g\t%g\t%g\t%g\t%g\t%g\t%g\t%g\t%g\t%g\t%g\t%g\t%g\t%g\n',A');
    fclose(fid);

    %writes tab separated textfile with the linear fits of run-in &
    %"elastic" curves in the form y=ax + b (considering seconds on x-axis)
    
    txtwriteRIG ([{'run-in slope "a"','run-in intersect "b" (MPa)','run-in intersect "b" (kN)','trad. HP (kN)', ...
    'real data HP (kN)','elastic slope "a"','elastic intersect "b"','time of hitpoint after start of datalogging (sec)'}; ...
    num2cell(fit1(1,1)) num2cell(runinintersectMPa) num2cell(runinintersectkN) num2cell(HPkN) num2cell(fHPkN) ...
    num2cell(fit2(1,1)) num2cell(fit2(1,2)) num2cell(tHPfromstart)],[name '_fits.txt']);

    %writes tab separated textfile with the input parameters
    
    txtwriteRIG ([{'rig','sample length','sample diameter','sample area (mm2)','Pc correction (y/n)','Rig Stiffnes (mm/kN)', ...
    'Force conversion factor (V/kN)','Pc conversion factor (V/MPa)','DC-DT conversion factor (V/mm)','record interval (sec)','datapoints used for forward & reverse running mean'}; ...
    num2cell(RIG) num2cell(slen) num2cell(sdia) num2cell(area) num2cell(pccorrection) num2cell(RigStiff) ...
    num2cell(fConkN) num2cell(pcCon) num2cell(dxCon) num2cell(ts) num2cell(no)],[name '_log.txt']);

else %Shear experiments
    [sdia,area,alfa,th0,thf,pccorrection,tau,gamma,sdif,sdifNoCor,shearrateI,shearrateF,shearrateR,disrate, ...
    disrateNoCor,runinintersectkN,runinintersectMPa,HPkN]=rigS(dxStiffCor,dxC,fCkN,pcC,tmin,tsec,name,fConkN, ...
    fit1,yintersect); %calls function rigS
   
    %----------------------------------------------------------------------
    %writes a tab separated textfile using fprintf (order of magnitude
    %faster than txtwrite), variable A contains all values to be printed,
    %first fprintf prints the header
    
    A=[tsec tmin thour tday sdifNoCor sdif tau fCkN pcC pcMPa dxC dxStiffCor gamma disrate shearrateI ...
    shearrateF shearrateR];
    fid= fopen([name '_shear.txt'],'wt');
    fprintf(fid,'t(sec)\tt(min)\tt(hour)\tt(day)\tdifferential_stress_raw (MPa)\tdifferential_stress_corrected_for_Pc(MPa)\tshear_stress(MPa)\tforce(kN)\tdelta_confining_pressure(MPa)\tconfining_pressure(MPa)\tdisplacement_raw(mm)\tdisplacement(mm)\tgamma\tdisplacement_rate(mm/sec)\tinstantaneous_shear_strain_rate(/sec)\tfinite_shear_strain_rate(/sec)\trennes_shear_rate(/sec)\n');
    fprintf(fid,'%g\t%g\t%g\t%g\t%g\t%g\t%g\t%g\t%g\t%g\t%g\t%g\t%g\t%g\t%g\t%g\t%g\n',A');
    fclose(fid);
    
    %writes tab separated textfile with the linear fits of run-in &
    %"elastic" curves in the form y=ax + b (considering seconds on x-axis)
    
    txtwriteRIG ([{'run-in slope "a"','run-in intersect "b" (MPa)','run-in intersect "b" (kN)','trad. HP (kN)', ...
    'real data HP (kN)','elastic slope "a"','elastic intersect "b"','time of hitpoint after start of datalogging (sec)'}; ...
    num2cell(fit1(1,1)) num2cell(runinintersectMPa) num2cell(runinintersectkN) num2cell(HPkN) num2cell(fHPkN) ...
    num2cell(fit2(1,1)) num2cell(fit2(1,2)) num2cell(tHPfromstart)],[name '_fits.txt']);

    %writes tab separated textfile with the input parameters
    
    txtwriteRIG ([{'rig','initial SZ thickness','final SZ thickness','angle of precut (degrees)','sample diameter', ...
    'sample area (mm2)','delta Pc correction (y/n)','Rig Stiffnes (mm/kN)','Force conversion factor (kN/V)', ...
    'Pc conversion factor (MPa/V)','DC-DT conversion factor (mm/V)','record interval (sec)','datapoints used for forward & reverse running mean'}; num2cell(RIG) ...
    num2cell(th0) num2cell(thf) num2cell(alfa) num2cell(sdia) num2cell(area) num2cell(pccorrection) num2cell(RigStiff) ...
    num2cell(fConkN) num2cell(pcCon) num2cell(dxCon) num2cell(ts) num2cell(no)],[name '_log.txt']);
end
