function [sdia,area,slen,pccorrection,strain,strainrateeng,strainratenat,sdifNoCor,sdif,sdifrawAreaCor,sdifAreaCor,strainraw,disrateNoCor,disrate,runinintersectkN,runinintersectMPa,HPkN]=rigC(dxStiffCor,dxC,fCkN,pcC,tmin,tsec,name,fConkN,fit1,yintersect) %[strain,strainrate,]=

%performs strain, stress, strain rate calculations for coaxial experiments
%Matej Pec 2010

%--------------------------------------------------------------------------
%calculate sigma1 displacement rate (delta L/delta t [mm/sec]) with dx
%corrected for rig stiffness

disrate=zeros(size(tsec));%prelocating matrix for higher calculation speed
for x=2:length(tsec);
    disrate(x)=(dxStiffCor(x)-dxStiffCor(x-1))/(tsec(x)-tsec(x-1));
end

%calculate sigma1 displacement rate (delta L/delta t [mm/sec]) with dx
%NOT corrected for rig stiffness

disrateNoCor=zeros(size(tsec));%prelocating matrix for higher calculation speed
for x=2:length(tsec);
    disrateNoCor(x)=(dxC(x)-dxC(x-1))/(tsec(x)-tsec(x-1));
end
%--------------------------------------------------------------------------
%read sample dimensions etc. for coaxial experiments

sdia= input ('Sample diameter (mm): ');
slen= input ('Sample lenght (mm): ');

%--------------------------------------------------------------------------
%calculate strain

e=zeros(size(fCkN));%prelocating matrix for higher calculation speed
for x=1:length(dxStiffCor)
    e(x)=slen-dxStiffCor(x);
end

strainraw=e/slen; 
strain=(1-strainraw)*100; %recalculate to %

%--------------------------------------------------------------------------
%calculates engineering (instantaneous) and natural (finite) strain rate from
%displacement rates CORRECTED for rig stiffness

strainrateeng=zeros(size(fCkN));%prelocating matrix for higher calculation speed
for x=1:length(fCkN);
    strainrateeng(x)=disrate(x)/e(x);
end

strainratenat=zeros(size(fCkN));%prelocating matrix for higher calculation speed
for x=1:length(fCkN);
    strainratenat(x)=disrate(x)/slen;
end

%----------------------------------------------------------------------
%calculates differential stress, correction for increasing sample diameter

fN=fCkN*1000; % convert kN to N
area=(pi*(sdia*sdia))/4; %area in mm2, N/mm2 = MPa since N/m2=Pa

sdifNoCor=zeros(size(fCkN)); %prelocating matrix for higher calculation speed
sdifrawAreaCor=zeros(size(fCkN));
for x=1:length(fCkN)
    sdifrawAreaCor(x)=fN(x)*strainraw(x)/area;
    sdifNoCor(x)=fN(x)/area; %no changing diameter correction
end

%--------------------------------------------------------------------------
%--------------------------------------------------------------------------
%calculate y-intersect of run in curve (in kN and MPa)

v=fit1(1,2)/1000; % convert into volts - Tromso specific
runinintersectkN=v*fConkN;
runinintersectMPa=v*fConkN*1000/area; % convert kN to N, area in mm2, N/mm2 = MPa since N/m2=Pa

%calculate intersect of run-in & elastic slopes(in kN) (i.e.
%traditionall hit-point)

HPkN=(yintersect/1000)*fConkN; %hitpoint in kN

%--------------------------------------------------------------------------
%correction for confining pressure change during run,

pccorrection= input ('Do you want to correct for changing confining pressure during experiment run (y/n)? ' ,'s');

if pccorrection == 'y';
    sdif = sdifNoCor - pcC;
    sdifAreaCor = sdifrawAreaCor - pcC;
    
    %----------------------------------------------------------------------
    %plots Pc corrected and uncorrected stress-strain curves to check if
    %data is ok
    
    figure
    plot(tmin,sdif,'r');
    
    hold on
    
    plot(tmin,sdifNoCor,'r--')
    
    title('differential stress (correction for changing Pc from area corrected data)');
    xlabel('time (min)');
    ylabel('diferential stress (MPa)');
    legend('corrected for changing Pc','uncorrected','Location','NorthWest');
    
    hold off
    
else
    sdif = sdifNoCor;
    sdifAreaCor = sdifrawAreaCor;
end

%--------------------------------------------------------------------------
%plots piston displacement rate, sample strainrates and stress-strain (including area correction) diagram

figure
plot(tmin,disrate,'g');

hold on

plot(tmin,disrateNoCor,'m--');

title('sigma1 piston displacement rate');
xlabel('time (min)');
ylabel('displacement rate (mm / sec)');
legend('corrected for rig stiffnes','NOT corrected for rig stiffness','Location','SouthWest');

hold off

figure
plot(strain,sdif,'r--');

hold on

plot(strain,sdifAreaCor,'r');

title('differential stress, changing area correction');
xlabel('stain (%)');
ylabel('differential stress (MPa)');
legend('uncorrected','corrected for changing area','Location','NorthWest');

hold off

figure
plot(tmin,strainrateeng,'m');

hold on

plot(tmin,strainratenat,'b');
title('strain rates');
xlabel('time (min)');
ylabel('strain rate (/ sec)');
legend('instantaneous strain rate','finite strain rate','Location','NorthWest');


hold off

figure
plot(strain,sdifAreaCor,'k');
title(name);
xlabel('strain (%)');
ylabel('stress (MPa)');