%stiffness
%%
%--------------------------------------------------------------------------
% convert to volts & read conversion factors
f=fi;
pc=pci;
dx=dxi;
DLT=DLTi;

tsec=ti*0.5;

[fV,dxV,pcV,fConkN,pcCon,dxCon,RigStiff,Friction]=conversionfactorsRIG2(f,dx,pc,DLT); 

%--------------------------------------------------------------------------
%recalculate all data to kN and mm (DLTmm is calculated in
%conversionfactorsRIG2)

fkN=fV*fConkN;
pcMPa=pcV*pcCon;
dxmm=dxV*dxCon;

%%
%hit-point definition

%--------------------------------------------------------------------------
%plot
plot(tsec,fkN,'r');
hold on
plot(tsec,pcMPa,'g');
plot(tsec,dxmm,'b');

title('zoom-in to your hit-point and then press ENTER, dashed lines = smoothed data');
xlabel('Time (sec)');
ylabel('force (kN)');
%legend('Force raw','Force smooth','Confining Pressure raw','Confining Pressure smooth','displacement raw','displacement smooth','Location','NorthWestOutside');

pause
dummy = input ('' ,'s'); %just to absorb the hit of any key to break the pause

%--------------------------------------------------------------------------
%fit chosen data (run-in)

title('Click a polygon enclosing data for linear regression on the force curve, start with the RUN-IN curve:');
[xx,yy]=getpoly;
if length(xx)>2
   ix=inpolygon(tsec,fkN,xx,yy);
else
   ix=1:length(fkN);
end
if isempty(find(ix)), ix=1:length(f); end  % take all

fitRUN=polyfit(tsec(ix),fkN(ix),1);
runin=fitRUN(1,1)*tsec + fitRUN(1,2);
plot(tsec,runin,'k--');

%--------------------------------------------------------------------------
%fit chosen data ("elastic" slope)

[xx,yy]=getpoly;
if length(xx)>2
   ix=inpolygon(tsec,fkN,xx,yy);
else
   ix=1:length(fkN);
end
if isempty(find(ix)), ix=1:length(f); end  % take all

fitELASTIC=polyfit(tsec(ix),fkN(ix),1);
elastic=fitELASTIC(1,1)*tsec + fitELASTIC(1,2);
plot(tsec,elastic,'k--');

%%
%--------------------------------------------------------------------------
%find x & y intersection of the line fits thru force

xintersect=(fitRUN(1,2)-fitELASTIC(1,2))/(fitELASTIC(1,1)-fitRUN(1,1));
yintersect=((fitRUN(1,2)*fitELASTIC(1,1))-(fitELASTIC(1,2)*fitRUN(1,1)))/(fitELASTIC(1,1)-fitRUN(1,1));

xintersect=int32(xintersect); %rounds up x-intersection to next integer 
%%
%--------------------------------------------------------------------------
%fit chosen data (run_in dx slope)

%smooth dxmm curve
no = 100

b=zeros(size(no)); %prelocating matrix
for x=1:no %creates a vector for forward & reverse moving average filter 
    b(x)=1/no;
end

dfilt=filtfilt(b,1,dxmm); %Zero-phase forward and reverse digital filtering

figure
a=[1:0.1:10];
plot(xintersect,a,'k')
%plot(tsec,fkN,'r');
hold on
plot(tsec,dxmm,'b');
plot(tsec,dfilt,'c');
pause
dummy = input ('' ,'s'); %just to absorb the hit of any key to break the pause


[xx,yy]=getpoly;
if length(xx)>2
   ix=inpolygon(tsec,dfilt,xx,yy);
else
   ix=1:length(dfilt);
end
if isempty(find(ix)), ix=1:length(dfilt); end  % take all

fitDX=polyfit(tsec(ix),dfilt(ix),1);
runindx=fitDX(1,1)*tsec + fitDX(1,2);
plot(tsec,runindx,'k--');

[xx,yy]=getpoly;
if length(xx)>2
   ix=inpolygon(tsec,dfilt,xx,yy);
else
   ix=1:length(dfilt);
end
if isempty(find(ix)), ix=1:length(dfilt); end  % take all

fitDX=polyfit(tsec(ix),dfilt(ix),1);
runindx=fitDX(1,1)*tsec + fitDX(1,2);
plot(tsec,runindx,'m--');

hold off

%%

dxdev=dxmm(840:2700); %first fit 1552
for x=1:length(dxdev);
dxdev0(x)=dxdev(x)-dxdev(1,1);
end

xx=[840:2700]; %where does the dx curve fit deviate from real dxmm?
dxlin=fitDX(1,2)+fitDX(1,1)*xx;

for x=1:length(dxlin);
dxlin0(x)=dxlin(x)-dxlin(1,1);
end

fkNcut=fkN(840:2700);

for x=1:length(fkNcut);
fkN0(x)=fkNcut(x)-fkNcut(1,1);
end

%%
%fit deviation curve - funny

fit=polyfit(dxlin0,fkN0,2);
cube=fit(1,1)*(dxlin0.^2) + fit(1,2)*dxlin0 + fit(1,3);

plot(dxlin0,cube,':m','LineWidth',2) 

%% fit the two slopes with linear fit manually

fit2=polyfit(fkN0(1:750),dxlin0(1:750),1); %806 = 1mm
lin2=fit2(1,1)*fkN0 + fit2(1,2);


fit3=polyfit(fkN0(1698:length(dxlin0)),dxlin0(1698:length(dxlin0)),1); %806 = 1mm
lin3=fit3(1,1)*fkN0 + fit3(1,2);

plot(fkN0,lin2,'--m') %,'LineWidth',2) 
hold on
plot(fkN0,lin3,'--k') %,'LineWidth',2)
plot(fkN0,dxlin0)
xlabel('force (kN)')
ylabel('delta dx (mm)')
%%
%--------------------------------------------------------------------------
%fit dxmm with linear curves for disrate

plot(tsec,dxmm);
pause
dummy = input ('' ,'s'); %just to absorb the hit of any key to break the pause

title('Click a polygon enclosing data for linear regression on the displacement curve');
xlabel('t (sec)');
ylabel('dx (mm)');

[xx,yy]=getpoly;
if length(xx)>2
   ix=inpolygon(tsec,dxmm,xx,yy);
else
   ix=1:length(dxmm);
end
if isempty(find(ix)), ix=1:length(dxmm); end  % take all

fit1=polyfit(tsec(ix),dxmm(ix),1);
dxfit=fit1(1,1)*tsec + fit1(1,2);
plot(tsec,dxfit,'k--');
hold off

%%
%fit dxmm vs. force [kN] with linear curves
figure
plot(dxmm,fkN,'r');
pause
dummy = input ('' ,'s'); %just to absorb the hit of any key to break the pause

title('Click a polygon enclosing data for linear regression start with loading');
xlabel('dx (mm)');
ylabel('force (kN)');

[xx,yy]=getpoly;
if length(xx)>2
   ix=inpolygon(dxmm,fkN,xx,yy);
else
   ix=1:length(dxmm);
end
if isempty(find(ix)), ix=1:length(dxmm); end  % take all

fit2=polyfit(dxmm(ix),fkN(ix),1);
fitdxfkN=fit2(1,1)*dxmm + fit2(1,2);
plot(dxmm,fitdxfkN,'k--');
hold on

[xx,yy]=getpoly;
if length(xx)>2
   ix=inpolygon(dxmm,fkN,xx,yy);
else
   ix=1:length(dxmm);
end
if isempty(find(ix)), ix=1:length(dxmm); end  % take all

fit3=polyfit(dxmm(ix),fkN(ix),1);
fitdxfkN2=fit3(1,1)*dxmm + fit3(1,2);
plot(dxmm,fitdxfkN2,'k--');

%%
%various calculations

x=[0:10];

load=fit2(1,1)*x;
unload=fit3(1,1)*x;

figure
plot(x,load);
hold on
plot(x,unload,'r');
xlabel('x');
ylabel('mm/kN');


